@@ -3,12 +3,13 @@ import pprint
 
 class ApiResponse:
     def __init__(self, payload=None, errors=None, pagination=None, headers=None, nextToken=None, **kwargs):
-        self.payload = payload
+        self.payload = payload or kwargs
         self.errors = errors
         self.pagination = pagination
         self.headers = headers
         self.next_token = self.set_next_token(nextToken)
-        self.kwargs = kwargs
+        if kwargs != self.payload:
+            self.kwargs = kwargs
 
     def __str__(self):
         return pprint.pformat(self.__dict__)
